@@ -1,8 +1,12 @@
 loo1nn <- function(x, y)
 {
-	stopifnot(class(x)=="pdclust")
+	stopifnot(class(x)=="pdclust" || class(x)=="dist")
 
-	D <- as.matrix(x$D)
+	if (class(x)=="dist") {
+		D <- as.matrix(x)
+	} else {
+		D <- as.matrix(x$D)
+	}
 	# set diagonal to have the largest entries
 	diag(D) <- max(D)+1
 	
